/** 
 *   Camera Control for STAR I.
 *
 *   (c) Copyright 2004 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/
#define _GNU_SOURCE

#include <unistd.h>
#include <limits.h>
#define USE_IAR_BUS
#  include "camera.h"
#include "my_stdio.h"
#include "socket_client.h"
#include "iar_bus.h"
#include "camera_tools.h"
#include "parse_tools.h"

char camera_server[_POSIX_PATH_MAX] = {CAMERA_HOST_NAME};
int camera_port = CAMERA_TCP_PORT;


int read_conf_client_file(char *filename)
{
	FILE *fp;
	char line[LINE_LEN_CONF];
	char *sline, *tag, *data, *comment;

	fp = fopen(filename, "r");
	
	if( fp == NULL ){
                SYSLOG(LOG_ERR,
                       "read_conf_client_file: Error opening file: %s",
		       filename);
                return -1;
        }
	
	memset(line, 0, sizeof(line));
	while( fgets(line, sizeof(line), fp)){
		if(line[strlen(line)-1] == '\n')
			line[strlen(line)-1] = 0;
		sline = stripwhite(line);
		if (parse_line(sline, &tag, &data, &comment) == 0){
			if( memcmp(tag,"SERVER", 6) == 0 ){
				sprintf(camera_server,"%s", data);
			}else if( memcmp(tag,"PORT", 4) == 0 ){
				camera_port = atoi(data);
			}else if( memcmp(tag,"WARNTEMP", 8) == 0 ){
				warn_temp = atoi(data);
				warn_temp_flag = 1;
			}

		}
		memset(line, 0, sizeof(line));
	}
	fclose(fp);

	return 0;
}


int open_camera(void)
{
	int dev;

	read_conf_client_file(CLIENT_CONFIG_FILE);
	dev = call_socket(camera_server, camera_port);

	return dev;
}


int close_camera(int dev)
{
	ibus_remove( dev );
	return close(dev);
}
